@@ -11,7 +11,7 @@
 #   },
 #   "server": {
 #     "host": "0.0.0.0",
-#     "post": "8089",
+#     "port": "8089",
 #     "monitor": "1000",
 #     "requesters": "1000",
 #     "workers": "1000",
@@ -29,7 +29,7 @@ ver = {"container_controller": "list",
        "container_filter": "list",
        "container_reject": "list",
        "server_host": "str",
-       "server_post": "int",
+       "server_port": "int",
        "server_monitor": "int",
        "server_requesters": "int",
        "server_workers": "int",
@@ -37,7 +37,7 @@ ver = {"container_controller": "list",
        "log_path": "str",
        "log_max": "int"}
 
-ver_int = {"server_post",
+ver_int = {"server_port",
            "server_monitor",
            "server_requesters",
            "server_workers",
@@ -52,13 +52,18 @@ ver_list = {"container_controller",
 class Setting:
     """
     Setting 类用来保存所有配置数据
+    ---------------------------------
+    0.2.4
+    端口号拼错了改一下
+    之前是post，现改为port
+    ---------------------------------
 
     Attributes:
         container_controller(list): controller包名
         container_filter(list): 过滤器包名
         container_reject(list): 拦截队列
         server_host(str): 主机号
-        server_post(int): 端口号
+        server_port(int): 端口号
         server_monitor(int): 监听者数量
         server_requesters(int): 请求队列长度
         server_workers(int): 工作内核数量
@@ -71,7 +76,7 @@ class Setting:
     container_filter = ["filter"]
     container_reject = []
     server_host = "0.0.0.0"
-    server_post = 8089
+    server_port = 8089
     server_monitor = 100
     server_requesters = 1000
     server_workers = 1000
@@ -95,7 +100,7 @@ class Setting:
         self.container_reject = []
 
         self.server_host = "0.0.0.0"
-        self.server_post = 8089
+        self.server_port = 8089
         self.server_monitor = 100
         self.server_requesters = 1000
         self.server_workers = 1000
